@@ -1,7 +1,7 @@
 /*============================================================================
 
-  WCSLIB 6.2 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2018, Mark Calabretta
+  WCSLIB 6.3 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2019, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -23,7 +23,7 @@
   Author: Michael Droetboom, Space Telescope Science Institute,
      and: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: twcs_locale.c,v 6.2 2018/10/20 10:03:14 mcalabre Exp $
+  $Id: twcs_locale.c,v 6.3 2019/07/12 07:33:39 mcalabre Exp $
 *=============================================================================
 *
 * twcs_locale tests wcslib's handling of locales, such as fr_FR, that use a
@@ -40,6 +40,7 @@
 #include "wcserr.h"
 #include "wcshdr.h"
 #include "wcsprintf.h"
+#include "wcsutil.h"
 
 #define HEADER_SIZE 36000
 
@@ -91,7 +92,7 @@ int main()
   wcshdo(1, wcsp, &nkeyrec, &gen_header);
   printf("%s", gen_header);
 
-  free(gen_header);
+  wcsdealloc(gen_header);
   wcsvfree(&nwcs, &wcs);
 
   return 0;
