@@ -1,7 +1,7 @@
 /*============================================================================
 
-  WCSLIB 6.2 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2018, Mark Calabretta
+  WCSLIB 6.3 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2019, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -22,7 +22,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: fitshdr.c,v 6.2 2018/10/20 10:03:14 mcalabre Exp $
+  $Id: fitshdr.c,v 6.3 2019/07/12 07:33:40 mcalabre Exp $
 *=============================================================================
 * Usage: fitshdr [infile]
 *-----------------------------------------------------------------------------
@@ -291,7 +291,7 @@ int main(int argc, char **argv)
       "bytes).\n", equals, ihdr, (ihdr == 1)?"":"s", iblock, blksiz, nbyte);
 
     if (argc > 1 && !stat(argv[i], &instat)) {
-      if (nbyte != instat.st_size) {
+      if ((off_t)nbyte != instat.st_size) {
         printf("WARNING: File is too short by %lld bytes.\n",
           nbyte - instat.st_size);
       }
